Learn R Programming

FinancialInstrument (version 1.4.1)

.to_daily: Extract a single row from each day in an xts object

Description

Extract a single row from each day in an xts object

Usage

.to_daily(x, EOD_time = "15:00:00")

Value

xts object with daily scale.

Arguments

x

xts object of sub-daily data.

EOD_time

time of day to use.

Author

Garrett See

See Also

quantmod:::to.daily, quantmod:::to.period