C2M: Month-to-Code and Code-to-Month

View source: R/MonthCodes.R

C2MR Documentation

Month-to-Code and Code-to-Month

Description

Convert month code (used for futures contracts) to abbreviated month name, or convert abbreviated month name to month code

Usage

C2M(code)

M2C(month)

Arguments

code

Month code: F, G, H, J, K, M, N , Q, U, V, X, or Z

month

Abbreviated month: jan, feb, mar, apr, may, jun, jul, aug, sep, oct, nov, or dec

Value

corresponding code or month.

Author(s)

Garrett See

See Also

MC2N

Examples

C2M()
C2M("M")
C2M()[6]
M2C()
M2C("Sep")
M2C()[9]

FinancialInstrument documentation built on Aug. 4, 2026, 5:10 p.m.