| all.equal.instrument | R Documentation |
This is most useful for seeing the difference between two instrument
objects.
## S3 method for class 'instrument'
all.equal(target, current, char.n = 2, collapse = ";", ...)
char.n |
If length of a character vector is |
collapse |
Only used if a character vector is of length less than
|
'TRUE' when 'target' and 'current' are equal. Otherwise, a character vector describing differences between the two objects.
ALPHA code. Subject to change
Garrett See
getInstrument, instrument.table,
buildHierarchy
currency("USD")
stock("SPY", "USD", validExchanges=c("SMART", "ARCA", "BATS", "BEX"))
stock("DIA", "USD", validExchanges=c("SMART", "ARCA", "ISLAND"),
ExtraField="something")
all.equal(getInstrument("SPY"), getInstrument("DIA"))
all.equal(getInstrument("SPY"), getInstrument("DIA"), char.n=5)
all.equal(getInstrument("SPY"), getInstrument("DIA"), char.n=5, collapse=NULL)
all.equal(getInstrument("DIA"), getInstrument("USD"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.