| expires.character | R Documentation |
If no instrument can be found by the id of x, or if the
instrument does not have an expires attribute, an attempt
will be made to infer the year and month of expiration using parse_id
in which case the returned value will be a string.
Presently, Date and expired will be ignored
if x is not the name of an instrument
## S3 method for class 'character'
expires(x, Date, expired = TRUE, silent = FALSE, ...)
Date |
Can be a Date or character string. When |
expired |
TRUE/FALSE. This determines which date will be used when
|
silent |
silence warnings? |
A 'Date' value representing the selected or inferred expiration date. If 'x' identifies a defined instrument, its stored expiration information is used; otherwise, the date is inferred from the identifier. May return 'NULL' when a defined instrument has no usable expiration.
Garrett See
expires.instrument
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.