find.instrument: Find the primary_ids of instruments that contain certain...

View source: R/find.instrument.R

find.instrumentR Documentation

Find the primary_ids of instruments that contain certain strings

Description

Uses regular expression matching to find instruments

Usage

find.instrument(
  text,
  where = "anywhere",
  Symbols = ls_instruments(),
  ignore.case = TRUE,
  exclude = NULL,
  ...
)

Arguments

text

character string containing a regular expression. This is used by grep (see also) as the pattern argument.

where

if “anywhere” all levels/attributes of the instruments will be searched. Otherwise, where can be used to specify in which levels/attributes to look. (e.g. c("name", "description") would only look for text in those 2 places.

Symbols

the character ids of instruments to be searched. All are are searched by default.

ignore.case

passed to grep; if FALSE, the pattern matching is case sensitive and if TRUE, case is ignored during matching.

exclude

character vector of names of levels/attributes that should not be searched.

...

other arguments to pass through to grep

Value

character vector of primary_ids of instruments that contain the sought after text.

Author(s)

Garrett See

See Also

buildHierarchy, instrument.table, regex

Examples

backup_file <- tempfile(fileext = ".RData")
saveInstruments(backup_file)

tryCatch(
  {
    rm_instruments(keep.currencies = FALSE)

    currency(c("USD", "EUR"))
    stock("SPY", "USD", description = "S&P 500 ETF")
    stock("DIA", "USD", description = "DJIA ETF")
    stock(
      c("AA", "AXP", "BA", "BAC", "CAT"),
      "USD",
      members.of = "DJIA"
    )
    stock("BMW", "EUR")

    find.instrument("ETF")
    find.instrument("DJIA")
    find.instrument("DJIA", where = "members.of")
    find.instrument("USD")
    find.instrument("EUR", Symbols = ls_stocks())
  },
  finally = {
    reloadInstruments(backup_file)
    unlink(backup_file)
  }
)

FinancialInstrument documentation built on Aug. 4, 2026, 5:10 p.m.