| is.currency.name | R Documentation |
currencycheck each element of a character vector to see if it is either the
primary_id or an identifier of a currency
is.currency.name(x)
x |
character vector |
A logical vector indicating whether each element of 'x' identifies a defined currency instrument. Non-character input returns 'FALSE'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.