View source: R/load.instruments.R
| setSymbolLookup.FI | R Documentation |
This function exists to tell getSymbols where to look
for your repository of market data.
setSymbolLookup.FI(
base_dir,
Symbols,
...,
split_method = c("days", "common"),
storage_method = "rda",
use_identifier = "primary_id",
extension = "rda",
src = "FI"
)
base_dir |
string specifying the base directory where data is stored, see Details |
Symbols |
character vector of names of instruments for which to |
... |
any other passthru parameters |
split_method |
string specifying the method files are split, currently ‘days’ or ‘common’, see Details |
storage_method |
currently only ‘rda’, but we will eventually support ‘indexing’ at least, and maybe others |
use_identifier |
string identifying which column should be use to construct the |
extension |
file extension, default "rda" |
src |
which |
The base_dir parameter must be set or the function will fail.
This will vary by your local environment and operating system. For mixed-OS
environments, we recommend doing some OS-detection and setting the network
share to your data to a common location by operating system. For example,
all Windows machines may use “M:/” and all *nix-style (linux, Mac)
machines may use “/mnt/mktdata/”.
The split_method currently allows either ‘days’ or
‘common’, and expects the file or files to be in sub-directories named
for the symbol. In high frequency data, it is standard practice to split
the data by days, which is why that option is the default.
No meaningful return value. Called for the side effect of updating the 'quantmod' symbol lookup table for the requested instruments.
getSymbols.FI,
instrument_attr,
load.instruments, loadInstruments,
setSymbolLookup
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.