sort.instrument: instrument class sort method

View source: R/instrument.R

sort.instrumentR Documentation

instrument class sort method

Description

instrument class sort method

Usage

## S3 method for class 'instrument'
sort(x, decreasing = FALSE, na.last = NA, ...)

Value

An instrument object of the same class as 'x'. Core fields remain first and additional named fields are sorted alphabetically.

Author(s)

Garrett See


FinancialInstrument documentation built on Aug. 4, 2026, 5:10 p.m.