View source: R/update_instruments.yahoo.R
| update_instruments.yahoo | R Documentation |
Adds/updates information in instrument with data downloaded from yahoo
update_instruments.yahoo(Symbols = c("stocks", "all"), verbose = FALSE)
update_instruments.TTR(
Symbols = c("stocks", "all"),
exchange = c("AMEX", "NASDAQ", "NYSE"),
silent = FALSE
)
Symbols |
can be a vector of instrument names, or, can be ‘all’
or ‘stocks’ or, for update_instruments.TTR, can be NULL in which case
all stocks found with |
verbose |
be verbose? |
exchange |
character vector of names of exchanges. Used in ‘TTR’ method. Can be “AMEX”, “NASDAQ”, or “NYSE” |
silent |
silence warnings? |
Although these functions are intended to update the metadata of
previously defined instruments, update_instruments.TTR will
define the stocks if they do not already exist.
update_instruments.TTR is only to be used on U.S. stocks denominated in USD.
called for side-effect
Garrett See
Yahoo! Finance "finance.yahoo.com" and YahooQuote
update_instruments.instrument,
update_instruments.morningstar,
update_instruments.masterDATA,
stockSymbols, stock
## Not run:
stock('GS',currency('USD'))
update_instruments.yahoo('GS')
getInstrument('GS')
update_instruments.TTR('GS')
getInstrument('GS')
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.