Learn R Programming

FinancialInstrument (version 1.4.1)

C2M: Month-to-Code and Code-to-Month

Description

Convert month code (used for futures contracts) to abbreviated month name, or convert abbreviated month name to month code

Usage

C2M(code)

M2C(month)

Value

corresponding code or month.

Arguments

code

Month code: F, G, H, J, K, M, N , Q, U, V, X, or Z

month

Abbreviated month: jan, feb, mar, apr, may, jun, jul, aug, sep, oct, nov, or dec

Author

Garrett See

See Also

MC2N

Examples

Run this code
C2M()
C2M("M")
C2M()[6]
M2C()
M2C("Sep")
M2C()[9]

Run the code above in your browser using DataLab