If no instrument can be found by the id of x, or if the
instrument does not have an expires attribute, an attempt
will be made to infer the year and month of expiration using parse_id
in which case the returned value will be a string.
Presently, Date and expired will be ignored
if x is not the name of an instrument
# S3 method for character
expires(x, Date, expired = TRUE, silent = FALSE, ...)A `Date` value representing the selected or inferred expiration date. If `x` identifies a defined instrument, its stored expiration information is used; otherwise, the date is inferred from the identifier. May return `NULL` when a defined instrument has no usable expiration.
Can be a Date or character string. When expires is a
vector, the retuned value will be one of the two values of expires
that are closest to Date. (which one will be determined by the value
of expired).
TRUE/FALSE. This determines which date will be used when
expires is a vector. If expired is TRUE the date
returned will be the last one before Date. If expired is
FALSE the first one after Date will be returned.
silence warnings?
Garrett See
expires.instrument