| expires.spread | R Documentation |
x$expires will be returned if it is not NULL. Otherwise, the
(character representation of the) exiration date of the first-to-expire of
the members will be returned.
## S3 method for class 'spread'
expires(x, Date, expired = TRUE, silent = FALSE, ...)
Date |
Can be a Date or character string. When |
expired |
TRUE/FALSE. This determines which date will be used when
|
A 'Date' value representing the spread expiration. The value is taken from the spread itself when available; otherwise, it is determined from the first-expiring member. May return 'NULL' if no expiration can be determined.
Garrett See
expires.instrument
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.