Learn R Programming

FinancialInstrument (version 1.4.1)

expires.spread: spread expires extraction method

Description

x$expires will be returned if it is not NULL. Otherwise, the (character representation of the) exiration date of the first-to-expire of the members will be returned.

Usage

# S3 method for spread
expires(x, Date, expired = TRUE, silent = FALSE, ...)

Value

A `Date` value representing the spread expiration. The value is taken from the spread itself when available; otherwise, it is determined from the first-expiring member. May return `NULL` if no expiration can be determined.

Arguments

Date

Can be a Date or character string. When expires is a vector, the retuned value will be one of the two values of expires that are closest to Date. (which one will be determined by the value of expired).

expired

TRUE/FALSE. This determines which date will be used when expires is a vector. If expired is TRUE the date returned will be the last one before Date. If expired is FALSE the first one after Date will be returned.

Author

Garrett See

See Also

expires.instrument