| sort.instrument | R Documentation |
instrument class sort method
## S3 method for class 'instrument'
sort(x, decreasing = FALSE, na.last = NA, ...)
An instrument object of the same class as 'x'. Core fields remain first and additional named fields are sorted alphabetically.
Garrett See
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.