Learn R Programming

FinancialInstrument (version 1.4.1)

sort.instrument: instrument class sort method

Description

instrument class sort method

Usage

# S3 method for instrument
sort(x, decreasing = FALSE, na.last = NA, ...)

Arguments

Value

An instrument object of the same class as `x`. Core fields remain first and additional named fields are sorted alphabetically.

Author

Garrett See