Learn R Programming

FinancialInstrument (version 1.4.1)

volep: generate endpoints for volume bars

Description

generate endpoints for volume bars

Usage

volep(x, units)

Value

An integer vector containing row positions where cumulative volume crosses successive multiples of `units`. These positions may be used as endpoints for constructing volume bars.

Arguments

x

time series containing 'Volume' column

units

volume sum to mark for bars

Author

Joshua Ulrich